@@ -78,12 +78,6 @@ impl<B: AsRef<[u8]>> Encode for BytesEncoder<B> {
     fn is_idle(&self) -> bool {
         self.bytes.is_none()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        self.bytes = None;
-        self.offset = 0;
-        Ok(())
-    }
 }
 impl<B: AsRef<[u8]>> ExactBytesEncode for BytesEncoder<B> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -130,6 +124,21 @@ impl<B> CopyableBytesDecoder<B> {
     pub fn new(bytes: B) -> Self {
         CopyableBytesDecoder { bytes, offset: 0 }
     }
+
+    /// Returns a reference to the inner bytes.
+    pub fn inner_ref(&self) -> &B {
+        &self.bytes
+    }
+
+    /// Returns a mutable reference to the inner bytes.
+    pub fn inner_mut(&mut self) -> &mut B {
+        &mut self.bytes
+    }
+
+    /// Takes ownership of this instance and returns the inner bytes.
+    pub fn into_inner(self) -> B {
+        self.bytes
+    }
 }
 impl<B: AsRef<[u8]> + AsMut<[u8]> + Copy> Decode for CopyableBytesDecoder<B> {
     type Item = B;
@@ -330,10 +339,6 @@ impl<S: AsRef<str>> Encode for Utf8Encoder<S> {
     fn is_idle(&self) -> bool {
         self.0.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        self.0.cancel()
-    }
 }
 impl<S: AsRef<str>> ExactBytesEncode for Utf8Encoder<S> {
     fn exact_requiring_bytes(&self) -> u64 {
