@@ -124,10 +124,6 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<C, F, E> ExactBytesEncode for MapErr<C, F, E>
 where
@@ -254,10 +250,6 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<E, T, F> ExactBytesEncode for MapFrom<E, T, F>
 where
@@ -312,10 +304,6 @@ where
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<C, T, E, F> ExactBytesEncode for TryMapFrom<C, T, E, F>
 where
@@ -385,12 +373,6 @@ where
     fn is_idle(&self) -> bool {
         self.items.is_none()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        self.items = None;
-        track!(self.inner.cancel())?;
-        Ok(())
-    }
 }
 
 /// Combinator for representing optional decoders.
@@ -467,10 +449,6 @@ impl<E: Encode> Encode for Optional<E> {
     fn is_idle(&self) -> bool {
         self.0.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.0.cancel())
-    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Optional<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -666,12 +644,6 @@ impl<E: Encode> Encode for Length<E> {
     fn is_idle(&self) -> bool {
         self.remaining_bytes == 0
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())?;
-        self.remaining_bytes = 0;
-        Ok(())
-    }
 }
 impl<E: Encode> ExactBytesEncode for Length<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -916,10 +888,6 @@ impl<E: Encode> Encode for MaxBytes<E> {
     fn is_idle(&self) -> bool {
         self.inner.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for MaxBytes<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -1010,11 +978,6 @@ impl<E: Encode> Encode for Padding<E> {
     fn is_idle(&self) -> bool {
         self.eos_reached
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        self.eos_reached = true;
-        Ok(())
-    }
 }
 
 /// Combinator for adding prefix items.
@@ -1072,12 +1035,6 @@ where
     fn is_idle(&self) -> bool {
         self.prefix_encoder.is_idle() && self.body_encoder.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.prefix_encoder.cancel())?;
-        track!(self.body_encoder.cancel())?;
-        Ok(())
-    }
 }
 impl<E0, E1, F> ExactBytesEncode for WithPrefix<E0, E1, F>
 where
@@ -1128,10 +1085,6 @@ impl<E: Encode> Encode for PreEncode<E> {
     fn is_idle(&self) -> bool {
         self.pre_encoded.is_idle()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.pre_encoded.cancel())
-    }
 }
 impl<E: Encode> ExactBytesEncode for PreEncode<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -1174,6 +1127,21 @@ impl<T> Slice<T> {
     pub fn is_suspended(&self) -> bool {
         self.consumable_bytes == 0
     }
+
+    /// Returns a reference to the inner encoder or decoder.
+    pub fn inner_ref(&self) -> &T {
+        &self.inner
+    }
+
+    /// Returns a mutable reference to the inner encoder or decoder.
+    pub fn inner_mut(&mut self) -> &mut T {
+        &mut self.inner
+    }
+
+    /// Takes ownership of this instance and returns the inner encoder or decoder.
+    pub fn into_inner(self) -> T {
+        self.inner
+    }
 }
 impl<D: Decode> Decode for Slice<D> {
     type Item = D::Item;
@@ -1216,10 +1184,6 @@ impl<E: Encode> Encode for Slice<E> {
     fn requiring_bytes(&self) -> ByteCount {
         self.inner.requiring_bytes()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Slice<E> {
     fn exact_requiring_bytes(&self) -> u64 {
@@ -1255,10 +1219,6 @@ impl<E: Encode> Encode for Last<E> {
     fn requiring_bytes(&self) -> ByteCount {
         self.inner.requiring_bytes()
     }
-
-    fn cancel(&mut self) -> Result<()> {
-        track!(self.inner.cancel())
-    }
 }
 impl<E: ExactBytesEncode> ExactBytesEncode for Last<E> {
     fn exact_requiring_bytes(&self) -> u64 {
